@@ -56,7 +56,7 @@ class accDisplay (hildon.Window):
 		self.tstamp = ""
 		self.period = 1.0/20
 		self.paused = True
-		self.smoothFlag = True
+		self.smoothFlag = False
 
 		self.set_title("Accelerometer Viewer")
 		self.build_gui()
@@ -103,9 +103,9 @@ class accDisplay (hildon.Window):
 
 	def filter(self, newM):
 		out = []
-		out.append(0.4*self.last_read[0]+0.6*newM[0])
-		out.append(0.4*self.last_read[1]+0.6*newM[1])
-		out.append(0.4*self.last_read[2]+0.6*newM[2])
+		out.append(0.9*self.last_read[0]+0.1*newM[0])
+		out.append(0.9*self.last_read[1]+0.1*newM[1])
+		out.append(0.9*self.last_read[2]+0.1*newM[2])
 		return out
 
 	def expose_handler(self, widget, event):
